@@ -10,9 +10,10 @@
 
 #include <QDialog>
 
-namespace EventViews {
+namespace EventViews
+{
 class Prefs;
-typedef QSharedPointer<Prefs> PrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
 
 class TimeScaleConfigDialog : public QDialog, private Ui::TimeScaleEditWidget
 {
