@@ -1,23 +1,7 @@
 /*
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_HELPER_H
 #define EVENTVIEWS_HELPER_H
@@ -27,7 +11,8 @@
 #include <QColor>
 #include <QSharedPointer>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 class Item;
 }
@@ -35,11 +20,15 @@ class Item;
 class QPixmap;
 class QDate;
 
-// Provides static methods that are useful to all views.
-
-namespace EventViews {
+// This include file declares static methods that are useful to all views.
+/**
+ * Namespace EventViews provides facilities for displaying incidences,
+ * including events, to-dos, and journal entries.
+ */
+namespace EventViews
+{
 class Prefs;
-typedef QSharedPointer<Prefs> PrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
 
 /**
  Returns a nice QColor for text, give the input color &c.
