@@ -10,13 +10,13 @@
 
 #include "prefs.h"
 
-#include <Akonadi/Calendar/IncidenceChanger>
 #include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/Calendar/IncidenceChanger>
 #include <Item>
 
+#include <EntityTreeModel>
 #include <KCalendarCore/Todo>
 #include <QAbstractItemModel>
-#include <EntityTreeModel>
 #include <QAbstractProxyModel>
 
 class QMimeData;
@@ -41,10 +41,7 @@ public:
     };
 
     /** This enum defines the user defined roles of the items in this model */
-    enum {
-        TodoRole = Akonadi::EntityTreeModel::UserRole + 1,
-        IsRichTextRole
-    };
+    enum { TodoRole = Akonadi::EntityTreeModel::UserRole + 1, IsRichTextRole };
 
     explicit TodoModel(const EventViews::PrefsPtr &preferences, QObject *parent = nullptr);
 
